# Höhere Mathematik
## Inhalt
- [Höhere Mathematik](#höhere-mathematik)
  - [Inhalt](#inhalt)
  - [Einführung](#einführung)
    - [Einsatzgebiet](#einsatzgebiet)
    - [Arten von Lösungen](#arten-von-lösungen)
    - [Verbindung zur Informatik](#verbindung-zur-informatik)
    - [Typische Fragestellungen](#typische-fragestellungen)
  - [Rechnerarithmetik](#rechnerarithmetik)
    - [Lernziele](#lernziele)
    - [Maschinenzahl](#maschinenzahl)
    - [Grenzen von Maschinenzahlen](#grenzen-von-maschinenzahlen)
    - [Datentypen gem. IEEE](#datentypen-gem-ieee)
    - [Rundungsfehler und Maschinengenauigkeit](#rundungsfehler-und-maschinengenauigkeit)
    - [Konditionszahl](#konditionszahl)
  - [Formelbuchstaben](#formelbuchstaben)
  - [Glossar](#glossar)

## Einführung
### Einsatzgebiet
  - Annähern komplexer Formeln in endlicher Zeit
  - Berechnung von Algorithmen durch Computer
    - Algorithmen ohne expliziter Lösungsdarstellung
    - Alternative Lösungsvorgänge für höhere Performance

### Arten von Lösungen
  - Direkte Verfahren - Exakte Lösung nach endlicher Zeit
  - Näherungsverfahren - Approximation nach begrenzter Anzahl Rechenschritte

### Verbindung zur Informatik
  - Effiziente Berechnung numerischer Algorithmen
  - Speicherung und Darstellung von Zahlen
  - Computergrafik & Bildverarbeitung
  - Neuronale Netze

### Typische Fragestellungen
  - Wie wirkt sich die Beschränkung der Anzahl Bits für Zahlenformate auf Rechenergebnisse und Rechengenauigkeit aus?
  - Numerische Lösung von Nullstellenproblemen
  - Numerische Integration

## Rechnerarithmetik
### Lernziele
  - [ ] Verstehen der Definition von maschinendarstellbaren Zahlen
  - [ ] Fehler von Maschinenzahlen sowie Maschinengenauigkeit berechnen
  - [ ] Fortpflanzung von Fehlern bei Funktionsanwendung abschätzen und Konditionszahl berechnen

### Maschinenzahl
Maschinenzahlen werden als Zahlen $x$ in folgender Form dargestellt:

$x = m \cdot B^e$

  - $x$: Die zu repräsentierende Zahl
  - $m$: Die Mantisse (der darstellbare Zahlenwert)
  - $B$: Die Basis der zu repräsentierenden Zahl
  - $e$: Der Exponent (der Stellenwert der Mantisse $m$)

Beispiel:
$1337 = 0.1337 * 10^4$

Maschinenzahlen sind normalisiert, wenn
  - für die Mantisse $m$ $0.1 <= |m| < 1.0$ zutrifft

Maschinenzahlen werden normalisiert, damit es zu jedem Wert eine eindeutige Darstellung als Maschinenzahl gibt.

### Grenzen von Maschinenzahlen
$x_{max} = B^{e_{max}} - B^{e_{max}-n} = (1 - B^{-n}) \cdot B^{e_{max}}$

$x_min = B^{e_{min} - 1}$

### Datentypen gem. IEEE
`float` oder `single`: 32 Bit - 1 Bit für Vorzeichen, 23 Bit für Mantisse $m$, 8 Bit für Exponent $e$

`double`: 64 Bit - 1 Bit für Vorzeichen, 52 für Mantisse $m$, 11 Bit für Exponent $e$

### Rundungsfehler und Maschinengenauigkeit
Absoluter Fehler:

$$|\tilde{x} - x|$$

Relativer Fehler:

$$\frac{|\tilde{x} - x|}{|x|}$$


Maximaler **absoluter** Rundungsfehler:

$$\frac{B}{2} \cdot B^{e - n - 1}$$

**Maschinengenauigkeit** oder maximaler **relativer** Rundungsfehler:

$$\frac{1}{2} \cdot B^{1 - n}$$

Fehlerfortpflanzung bei Funktionsauswertung:

Relativ:

$$\frac{f'(x) \cdot x}{f(x)} \cdot \frac{\tilde{x} - x}{x}$$

Absolut:

$$|f'(x)| \cdot |\tilde{x} - x|$$

  - $B$: Die Basis der Maschinenzahl
  - $e$: Der Exponent der Maschinenzahl (Standard-Wert: $0$)
  - $n$: Die Anzahl Stellen der Mantisse $m$
  - $x$: Der darzustellende Wert
  - $\tilde{x}$: Die Annäherung/Approximation an $x$
  - $f$: Auszuwertende Funktion

### Konditionszahl
Die Konditionszahl gibt an, wie gross der potenzielle relative Fehler einer numerischen Lösung ist.

Eine niedrige Konditionszahl ($K \le 1$) bedeutet einen niedrigen Fehler, eine hohe Konditionszahl ein grosses Fehlerrisiko.

Formel:

$$K = \frac{|f'(x)| \cdot |x|}{|f(x)|}$$

## Formelbuchstaben
  - $B$: Basis der Maschinenzahl
  - $e$: Exponent der Maschinenzahl
  - $K$: Konditionszahl
  - $m$: Mantisse (Darstellbarer Bereich der Maschinenzahl)
  - $n$: Anzahl möglicher Stellen der Mantisse $m$
  - $x$: Darzustellender Wert
  - $\tilde{x}$: Approximation/Annäherung an $x$
## Glossar
